@@ -31,7 +31,7 @@
 #' Passing to \code{\link[data.table:data.table]{data.table}}:
 #' \code{DT[ , , by]}
 #' @param drop Drop existing variables and return only new variables?
-#' Default is \code{FALSE}, which returns all variables.
+#' Defaults to \code{FALSE}, which returns all variables.
 #'
 #' @return
 #' \code{add()} returns a new
@@ -241,8 +241,8 @@ RESCALE = function(var, from=range(var, na.rm=T), to) {
 #' and it is just equivalent to \code{RESCALE(var, to=0:1)}.
 #'
 #' @param v Variable (numeric vector).
-#' @param min Minimum value (default is 0).
-#' @param max Maximum value (default is 1).
+#' @param min Minimum value (defaults to 0).
+#' @param max Maximum value (defaults to 1).
 #'
 #' @return A vector of rescaled variable.
 #'
@@ -263,7 +263,7 @@ scaler = function(v, min=0, max=1) {
 #'
 #' @param z,t,f,r,chi2 \emph{z}, \emph{t}, \emph{F}, \emph{r}, \eqn{\chi}^2 value.
 #' @param n,df,df1,df2 Sample size or degree of freedom.
-#' @param digits,nsmall Number of decimal places of output. Default is \code{2}.
+#' @param digits Number of decimal places of output. Defaults to \code{2}.
 #'
 #' @return \emph{p} value statistics.
 #'
@@ -282,22 +282,22 @@ scaler = function(v, min=0, max=1) {
 #'
 #' @export
 p = function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
-             n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
-  if(!is.null(z)) {p = p.z(z); pstat = Glue("<<italic z>> = {z:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("<<italic t>>({df}) = {t:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("<<italic F>>({df1}, {df2}) = {f:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("<<italic r>>({n-2}) = {r:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', <<italic N>> = ' %^% n)}) = {chi2:.{nsmall}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+             n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2) {
+  if(!is.null(z)) {p = p.z(z); pstat = Glue("<<italic z>> = {z:.{digits}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("<<italic t>>({df}) = {t:.{digits}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("<<italic F>>({df1}, {df2}) = {f:.{digits}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("<<italic r>>({n-2}) = {r:.{digits}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', <<italic N>> = ' %^% n)}) = {chi2:.{digits}}, <<italic p>> {p.trans2(p)} {sig.trans(p)}")}
   return(pstat)
 }
 
 p.plain = function(z=NULL, t=NULL, f=NULL, r=NULL, chi2=NULL,
-                   n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2, nsmall=digits) {
-  if(!is.null(z)) {p = p.z(z); pstat = Glue("z = {z:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("t({df}) = {t:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("F({df1}, {df2}) = {f:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("r({n-2}) = {r:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
-  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', N = ' %^% n)}) = {chi2:.{nsmall}}, p {p.trans2(p)} {sig.trans(p)}")}
+                   n=NULL, df=NULL, df1=NULL, df2=NULL, digits=2) {
+  if(!is.null(z)) {p = p.z(z); pstat = Glue("z = {z:.{digits}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(t)) {p = p.t(t, df); pstat = Glue("t({df}) = {t:.{digits}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(f)) {p = p.f(f, df1, df2); pstat = Glue("F({df1}, {df2}) = {f:.{digits}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(r)) {p = p.r(r, n); pstat = Glue("r({n-2}) = {r:.{digits}}, p {p.trans2(p)} {sig.trans(p)}")}
+  if(!is.null(chi2)) {p = p.chi2(chi2, df); pstat = Glue("\u03c7\u00b2({df}{ifelse(is.null(n), '', ', N = ' %^% n)}) = {chi2:.{digits}}, p {p.trans2(p)} {sig.trans(p)}")}
   return(pstat)
 }
 
@@ -325,7 +325,7 @@ p.chi2 = function(chi2, df) ifelse(df==0, 1, pchisq(chi2, df, lower.tail=FALSE))
 ## Transform \emph{p} value.
 ##
 ## @param p \emph{p} value.
-## @param nsmall.p Number of decimal places of \emph{p} value. Default is \code{3}.
+## @param nsmall.p Number of decimal places of \emph{p} value. Defaults to \code{3}.
 ##
 ## @return A character string of transformed \emph{p} value.
 ##
@@ -335,19 +335,19 @@ p.chi2 = function(chi2, df) ifelse(df==0, 1, pchisq(chi2, df, lower.tail=FALSE))
 ## @seealso \code{\link{p.trans2}}
 ##
 ## @export
-p.trans = function(p, nsmall.p=3) {
-  mapply(function(p, nsmall.p) {
+p.trans = function(p, digits.p=3) {
+  mapply(function(p, digits.p) {
     ifelse(is.na(p) | p > 1 | p < 0, "",
-           ifelse(p < 10^-nsmall.p, gsub("0(?=\\.)", "", Glue("<{10^-nsmall.p:.{nsmall.p}}"), perl=T),
-                  gsub("0(?=\\.)", " ", Glue("{p:.{nsmall.p}}"), perl=T)))
-  }, p, nsmall.p)
+           ifelse(p < 10^-digits.p, gsub("0(?=\\.)", "", Glue("<{10^-digits.p:.{digits.p}}"), perl=T),
+                  gsub("0(?=\\.)", " ", Glue("{p:.{digits.p}}"), perl=T)))
+  }, p, digits.p)
 }
 
 
 ## Transform \emph{p} value.
 ##
 ## @inheritParams p.trans
-## @param p.min Minimum of \emph{p}. Default is \code{1e-99}.
+## @param p.min Minimum of \emph{p}. Defaults to \code{1e-99}.
 ##
 ## @return A character string of transformed \emph{p} value.
 ##
@@ -357,11 +357,11 @@ p.trans = function(p, nsmall.p=3) {
 ## @seealso \code{\link{p.trans}}
 ##
 ## @export
-p.trans2 = function(p, nsmall.p=3, p.min=1e-99) {
+p.trans2 = function(p, digits.p=3, p.min=1e-99) {
   ifelse(is.na(p) | p > 1 | p < 0, "",
          ifelse(p < p.min, paste("<", p.min),
-                ifelse(p < 10^-nsmall.p, paste("=", format(p, digits=1, scientific=TRUE)),
-                       paste("=", formatF(p, nsmall=nsmall.p)))))
+                ifelse(p < 10^-digits.p, paste("=", format(p, digits=1, scientific=TRUE)),
+                       paste("=", formatF(p, digits=digits.p)))))
 }
 
 
@@ -384,6 +384,15 @@ sig.trans = function(p) {
 }
 
 
+sig.trans2 = function(p) {
+  ifelse(is.na(p) | p > 1 | p < 0, "",
+         ifelse(p < .001, "***",
+                ifelse(p < .01, "**",
+                       ifelse(p < .05, "*", ""))))
+}
+
+
+
 
 #### Basic Statistics ####
 
@@ -392,7 +401,7 @@ sig.trans = function(p) {
 #' @param data Data frame or numeric vector.
 #' @param all.as.numeric \code{TRUE} (default) or \code{FALSE}.
 #' Transform all variables into numeric (continuous).
-#' @param digits,nsmall Number of decimal places of output. Default is \code{2}.
+#' @param digits Number of decimal places of output. Defaults to \code{2}.
 #' @param file File name of MS Word (\code{.doc}).
 #' @param plot \code{TRUE} or \code{FALSE} (default).
 #' Visualize the descriptive statistics using \code{\link[GGally:ggpairs]{GGally::ggpairs()}}.
@@ -401,14 +410,14 @@ sig.trans = function(p) {
 #' @param upper.smooth \code{"none"} (default), \code{"lm"}, or \code{"loess"}.
 #' Add fitting lines to scatter plots (if any).
 #' @param plot.file \code{NULL} (default, plot in RStudio) or a file name (\code{"xxx.png"}).
-#' @param plot.width Width (in "inch") of the saved plot. Default is \code{8}.
-#' @param plot.height Height (in "inch") of the saved plot. Default is \code{6}.
-#' @param plot.dpi DPI (dots per inch) of the saved plot. Default is \code{500}.
+#' @param plot.width Width (in "inch") of the saved plot. Defaults to \code{8}.
+#' @param plot.height Height (in "inch") of the saved plot. Defaults to \code{6}.
+#' @param plot.dpi DPI (dots per inch) of the saved plot. Defaults to \code{500}.
 #'
 #' @return
-#' Invisibly return a list consisting of
+#' Invisibly return a list with
 #' (1) a data frame of descriptive statistics and
-#' (2) a \code{ggplot2} object if users set \code{plot=TRUE}.
+#' (2) a \code{ggplot2} object if \code{plot=TRUE}.
 #'
 #' @examples
 #' \donttest{set.seed(1)
@@ -436,13 +445,15 @@ sig.trans = function(p) {
 #' @seealso \code{\link{Corr}}
 #'
 #' @export
-Describe = function(data,
-                    all.as.numeric=TRUE,
-                    digits=2, nsmall=digits,
-                    file=NULL,
-                    plot=FALSE,
-                    upper.triangle=FALSE, upper.smooth="none",
-                    plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
+Describe = function(
+    data,
+    all.as.numeric=TRUE,
+    digits=2,
+    file=NULL,
+    plot=FALSE,
+    upper.triangle=FALSE, upper.smooth="none",
+    plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500
+) {
   if(is.numeric(data)) data = data.frame(X=data)
   desc = as.data.frame(psych::describe(data, fast=FALSE))
   desc$vars = desc$trimmed = desc$mad = desc$range = desc$se = NULL
@@ -457,13 +468,13 @@ Describe = function(data,
   missing = nrow(data) - desc$N
   if(max(missing)==0) {
     desc$Missing = NULL
-    nsmalls = c(0, rep(nsmall, 8))
+    nsmalls = c(0, rep(digits, 8))
   } else {
     desc$Missing = ifelse(missing==0, NA, missing)
     names(desc)[2] = "(NA)"
-    nsmalls = c(0, 0, rep(nsmall, 8))
+    nsmalls = c(0, 0, rep(digits, 8))
   }
-  print_table(desc, nsmalls=nsmalls, file=file,
+  print_table(desc, digits=nsmalls, file=file,
               title="Descriptive Statistics:")
 
   data.new = as.data.frame(data)
@@ -481,8 +492,6 @@ Describe = function(data,
 
   p = NULL
   if(plot) {
-    # if(!pacman::p_isinstalled("GGally"))
-    #   stop("Package `GGally` needs to be installed for plotting.\nRun this code: install.packages(\"GGally\")", call.=FALSE)
     if(upper.triangle) {
       smooth = switch(upper.smooth,
                       "none"="points",
@@ -497,13 +506,13 @@ Describe = function(data,
       data.new, switch="both", axisLabels="none",
       upper=upper,
       lower=list(continuous=GGally::wrap(
-        "cor", digits=nsmall,
+        "cor", digits=digits,
         use="pairwise.complete.obs",
         size=4, color="black"))) +
       theme_bruce() +
       theme(strip.text=element_text(size=12, color="black"))
     if(is.null(plot.file)) {
-      print(p)
+      suppressWarnings(print(p))
     } else {
       ggsave(plot=p, filename=plot.file,
              width=plot.width, height=plot.height, dpi=plot.dpi)
@@ -524,7 +533,7 @@ Describe = function(data,
 #' @param labels [Optional] A vector re-defining the labels of values.
 #' @param sort \code{""} (default, sorted by the order of variable values/labels),
 #' \code{"-"} (decreasing by N), or \code{"+"} (increasing by N).
-#' @param digits,nsmall Number of decimal places of output. Default is \code{1}.
+#' @param digits Number of decimal places of output. Defaults to \code{1}.
 #' @param file File name of MS Word (\code{.doc}).
 #'
 #' @return A data frame of frequency statistics.
@@ -543,8 +552,10 @@ Describe = function(data,
 #' Freq(data, "age")
 #'
 #' @export
-Freq = function(x, varname, labels, sort="",
-                digits=1, nsmall=digits, file=NULL) {
+Freq = function(
+    x, varname, labels, sort="",
+    digits=1, file=NULL
+) {
   if(inherits(x, "data.frame")) {
     if(missing(varname))
       stop("Please also specify `varname` (variable name). See help page: help(Freq)", call.=FALSE)
@@ -560,10 +571,10 @@ Freq = function(x, varname, labels, sort="",
   if(missing(labels)) labels = names(table.var)
   output = cbind(matrix(table.var,
                         dimnames=list(labels, "N")),
-                 matrix(round(table.var/N*100, nsmall),
+                 matrix(round(table.var/N*100, digits),
                         dimnames=list(labels, "%")))
   if(N.na) output = rbind(output,
-                          matrix(c(N.na, round(N.na/N*100, nsmall)),
+                          matrix(c(N.na, round(N.na/N*100, digits)),
                                  ncol=2, dimnames=list("(NA)")))
   if(sort=="-")
     output = output[order(output[,"N"], decreasing=TRUE),]
@@ -579,7 +590,7 @@ Freq = function(x, varname, labels, sort="",
     if(N.na>0) note = note %^% "</p>\n<p>" %^%
         "Valid <i>N</i> = " %^% formatN(N-N.na)
   }
-  print_table(output, nsmalls=c(0, nsmall), file=file,
+  print_table(output, digits=c(0, digits), file=file,
               title="Frequency Statistics:", note=note)
 
   invisible(output)
@@ -594,21 +605,22 @@ Freq = function(x, varname, labels, sort="",
 #' @param p.adjust Adjustment of \emph{p} values for multiple tests:
 #' \code{"none"}, \code{"fdr"}, \code{"holm"}, \code{"bonferroni"}, ...
 #' For details, see \code{\link[stats:p.adjust]{stats::p.adjust()}}.
-#' @param digits,nsmall Number of decimal places of output. Default is \code{2}.
+#' @param digits Number of decimal places of output. Defaults to \code{2}.
 #' @param file File name of MS Word (\code{.doc}).
 #' @param plot \code{TRUE} (default) or \code{FALSE}. Plot the correlation matrix.
-#' @param plot.range Range of correlation coefficients for plot. Default is \code{c(-1, 1)}.
-#' @param plot.palette Color gradient for plot. Default is \code{c("#B52127", "white", "#2171B5")}.
-#' You may also set it to, e.g., \code{c("red", "white", "blue")}.
-#' @param plot.color.levels Default is \code{201}.
+#' @param plot.r.size Font size of correlation text label. Defaults to \code{4}.
+#' @param plot.colors Plot colors (character vector). Defaults to "RdBu" of the Color Brewer Palette.
 #'
 #' @return
-#' Invisibly return the correlation results obtained from
-#' \code{\link[psych:corr.test]{psych::corr.test()}}.
+#' Invisibly return a list with
+#' (1) correlation results from
+#' \code{\link[psych:corr.test]{psych::corr.test()}} and
+#' (2) a \code{ggplot2} object if \code{plot=TRUE}.
 #'
 #' @examples
 #' Corr(airquality)
-#' Corr(airquality, p.adjust="bonferroni")
+#' Corr(airquality, p.adjust="bonferroni",
+#'      plot.colors=c("#b2182b", "white", "#2166ac"))
 #'
 #' d = as.data.table(psych::bfi)
 #' added(d, {
@@ -622,18 +634,24 @@ Freq = function(x, varname, labels, sort="",
 #' })
 #' Corr(d[, .(age, gender, education, E, A, C, N, O)])
 #'
-#' @seealso \code{\link{Describe}}
+#' @seealso
+#' \code{\link{Describe}}
+#'
+#' \code{\link{cor_multilevel}}
 #'
 #' @export
-Corr = function(data,
-                method="pearson",
-                p.adjust="none",
-                all.as.numeric=TRUE,
-                digits=2, nsmall=digits,
-                file=NULL,
-                plot=TRUE, plot.range=c(-1, 1),
-                plot.palette=NULL, plot.color.levels=201,
-                plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500) {
+Corr = function(
+    data,
+    method="pearson",
+    p.adjust="none",
+    all.as.numeric=TRUE,
+    digits=2,
+    file=NULL,
+    plot=TRUE,
+    plot.r.size=4,
+    plot.colors=NULL,
+    plot.file=NULL, plot.width=8, plot.height=6, plot.dpi=500
+) {
   data.new = as.data.frame(data)
   vars.not.numeric = c()
   if(all.as.numeric) {
@@ -650,17 +668,17 @@ Corr = function(data,
                          minlength=20)
   COR = cor$ci["r"]
   if(p.adjust=="none") {
-    COR$`[95% CI]` = cc_ci(cor$ci$lower, cor$ci$upper, nsmall)
+    COR$`[95% CI]` = cc_ci(cor$ci$lower, cor$ci$upper, digits)
     COR$pval = cor$ci$p
   } else {
-    COR$`[95% CI]` = cc_ci(cor$ci.adj$lower, cor$ci.adj$upper, nsmall)
+    COR$`[95% CI]` = cc_ci(cor$ci.adj$lower, cor$ci.adj$upper, digits)
     COR$pval = p.adjust(cor$ci$p, method=p.adjust)
   }
   if(inherits(cor$n, "matrix"))
     Ns = cor$n[lower.tri(cor$n)]
   else
     Ns = cor$n
-  COR$r = formatF(COR$r, nsmall)
+  COR$r = formatF(COR$r, digits)
   COR$N = Ns
 
   if(length(vars.not.numeric)>0) {
@@ -668,53 +686,15 @@ Corr = function(data,
     cat("\n")
   }
 
-  if(plot) {
-    if(is.null(plot.palette))
-      plot.palette = c("#B52127", "white", "#2171B5")
-    if(!is.null(plot.file)) {
-      grDevices::png(filename=plot.file, width=plot.width, height=plot.height, units="in", res=plot.dpi)
-    }
-    try({
-      plot.error = TRUE
-      cor_plot(r=cor$r, adjust="none", nsmall=nsmall,
-               numbers=TRUE, zlim=plot.range,
-               diag=FALSE, xlas=2, n=plot.color.levels,
-               pval=cor$p, stars=TRUE,
-               alpha=1, gr=grDevices::colorRampPalette(plot.palette),
-               main="Correlation Matrix")
-      plot.error = FALSE
-    }, silent=TRUE)
-    if(plot.error) {
-      warning = Glue("
-        Plot is NOT successfully displayed in the RStudio `Plots` Pane.
-        Please check if the `Plots` Pane of your RStudio is too small.
-        You should enlarge the `Plots` Pane (and/or clear all plots).")
-      warning(warning, call.=TRUE)
-      cat("\n")
-    } else {
-      Print("Correlation matrix is displayed in the RStudio `Plots` Pane.")
-      if(p.adjust!="none")
-        Print("<<blue <<italic p>> values ABOVE the diagonal are adjusted using the \"{p.adjust}\" method.>>")
-      cat("\n")
-    }
-    if(!is.null(plot.file)) {
-      grDevices::dev.off()
-      plot.file = str_split(plot.file, "/", simplify=TRUE)
-      plot.path = paste0(getwd(), '/', plot.file[length(plot.file)])
-      Print("<<green \u2714>> Plot saved to <<blue '{plot.path}'>>")
-      cat("\n")
-    }
-  }
-
   if(is.null(file)) {
     Print("{capitalize(method)}'s <<italic r>> and 95% confidence intervals:")
     if(p.adjust!="none")
       Print("<<blue <<italic p>> values and 95% CIs are adjusted using the \"{p.adjust}\" method.>>")
-    print_table(COR, nsmalls=0)
+    print_table(COR, digits=0)
     cat("\n")
   } else {
     Print("Descriptive Statistics and Correlation Matrix:")
-    cor.mat = matrix(formatF(cor$r, nsmall),
+    cor.mat = matrix(formatF(cor$r, digits),
                      nrow=nrow(cor$r),
                      dimnames=list(rownames(cor$r),
                                    colnames(cor$r)))
@@ -768,7 +748,7 @@ Corr = function(data,
              " <i>p</i> values and 95% CIs are adjusted using the \"" %^% p.adjust %^% "\" method.</p>")
     )
     print_table(
-      des.cor, nsmalls=nsmall, row.names=FALSE,
+      des.cor, digits=digits, row.names=FALSE,
       title="<b>Table 1. Descriptive Statistics and Correlation Matrix.</b>",
       note=paste0(
         "<i>Note</i>. ",
@@ -784,219 +764,56 @@ Corr = function(data,
     )
   }
 
-  invisible(cor)
-}
 
+  p = label = r = x = y = NULL
+  if(plot) {
+    dcor = cbind(expand.grid(y=row.names(cor$r), x=row.names(cor$r)),
+                 data.frame(r=as.numeric(cor$r), p=as.numeric(cor$p)))
+    dcor$label = str_replace(str_replace(
+      str_trim(formatF(dcor$r, digits)), "0\\.", "."), "-", "\u2013") %^%
+      sig.trans2(dcor$p)
+    colors = c("#67001f", "#b2182b", "#d6604d", "#f4a582",
+               "#fddbc7", "#f7f7f7", "#d1e5f0", "#92c5de",
+               "#4393c3", "#2166ac", "#053061")
+    if(is.null(plot.colors))
+      plot.colors = grDevices::colorRampPalette(colors)(100)
+    p = ggplot(dcor[which(dcor$x!=dcor$y),],
+               aes(x=x, y=y, fill=r)) +
+      geom_tile() +
+      geom_text(aes(label=label), size=plot.r.size) +
+      scale_x_discrete(position="top", expand=expansion(add=0)) +
+      scale_y_discrete(limits=rev, expand=expansion(add=0)) +
+      # scale_fill_fermenter(
+      #   palette="RdBu", direction=1,
+      #   limits=c(-1, 1), breaks=seq(-1, 1, 0.2),
+      #   guide=guide_colorsteps(barwidth=0.5, barheight=10)) +
+      scale_fill_stepsn(
+        colors=plot.colors,
+        limits=c(-1, 1), breaks=seq(-1, 1, 0.1),
+        labels=function(x) ifelse(x %in% seq(-1, 1, 0.2), x, ""),
+        guide=guide_colorsteps(barwidth=0.5, barheight=10)) +
+      coord_equal() +
+      labs(x=NULL, y=NULL, fill=NULL) +
+      theme_bruce(border=TRUE, line.x=FALSE, line.y=FALSE,
+                  tick.x=FALSE, tick.y=FALSE) +
+      theme(axis.text.x=element_text(hjust=0, angle=45))
+    if(is.null(plot.file)) {
+      print(p)
+      Print("Correlation matrix is displayed in the RStudio `Plots` Pane.")
+      if(p.adjust!="none")
+        Print("<<blue <<italic p>> values ABOVE the diagonal are adjusted using the \"{p.adjust}\" method.>>")
+      cat("\n")
+    } else {
+      ggsave(plot=p, filename=plot.file,
+             width=plot.width, height=plot.height, dpi=plot.dpi)
+      plot.file = str_split(plot.file, "/", simplify=TRUE)
+      plot.path = paste0(getwd(), '/', plot.file[length(plot.file)])
+      Print("<<green \u2714>> Plot saved to <<blue '{plot.path}'>>")
+      cat("\n")
+    }
+  }
 
-
-## modified `psych::cor.plot()`
-## see comment lines
-cor_plot <- function (r, numbers = TRUE, colors = TRUE, n = 51, main = NULL,
-  zlim = c(-1, 1), show.legend = TRUE, labels = NULL, n.legend = 10,
-  select = NULL, pval = NULL, cuts = c(0.001, 0.01), scale = TRUE,
-  cex, MAR, upper = TRUE, diag = TRUE,
-  symmetric = TRUE, stars = FALSE, adjust = "holm", xaxis = 1,
-  xlas = 0, ylas = 2, gr = NULL, alpha = 0.75, min.length = NULL,
-  nsmall=2,  # added in bruceR
-  ...)
-{
-  oldpar <- graphics::par(no.readonly = TRUE)
-  on.exit(graphics::par(oldpar))
-  if (missing(MAR))
-    # MAR <- 5
-    MAR <- 4
-  if (!is.matrix(r) & (!is.data.frame(r))) {
-    if ((length(class(r)) > 1) & (inherits(r, "psych"))) {
-      switch(class(r)[2], omega = {
-        r <- r$schmid$sl
-        nff <- ncol(r)
-        r <- r[, 1:(nff - 3)]
-        if (is.null(main)) {
-          main <- "Omega plot"
-        }
-      }, cor.ci = {
-        pval <- 2 * (1 - r$ptci)
-        r <- r$rho
-      }, fa = {
-        r <- r$loadings
-        if (is.null(main)) {
-          main <- "Factor Loadings plot"
-        }
-      }, pc = {
-        r <- r$loadings
-        if (is.null(main)) {
-          main <- "PCA Loadings plot"
-        }
-      }, principal = {
-        r <- r$loadings
-        if (is.null(main)) {
-          main <- "PCA Loadings plot"
-        }
-      })
-    }
-  }
-  else {
-    if (symmetric & !psych::isCorrelation(r) & (nrow(r) != ncol(r))) {
-      cp <- psych::corr.test(r, adjust = adjust)
-      r <- cp$r
-      pval <- cp$p
-      if (is.null(main)) {
-        main <- "Correlation plot"
-      }
-    }
-  }
-  R <- r <- as.matrix(r)
-  if (!is.null(select))
-    r <- r[select, select]
-  if (min(dim(r)) < 2) {
-    stop("You need at least two dimensions to make a meaningful plot.", call.=TRUE)
-  }
-  if (is.null(n)) {
-    n <- dim(r)[2]
-  }
-  nf <- dim(r)[2]
-  nvar <- dim(r)[1]
-  if (!upper)
-    r[col(r) > row(r)] <- NA
-  if (!diag)
-    r[col(r) == row(r)] <- NA
-  if (nf == nvar)
-    r <- t(r)
-  if (missing(pval) | is.null(pval)) {
-    pval <- matrix(rep(1, nvar * nf), nvar)
-  }
-  else {
-    if (length(pval) != nvar * nf) {
-      pr = matrix(0, nvar, nf)
-      pr[row(pr) > col(pr)] <- pval
-      pr <- pr + t(pr)
-      diag(pr) <- 0
-      pval <- pr
-    }
-    if (!stars) {
-      pval <- psych::con2cat(pval, cuts = cuts)
-      pval <- (length(cuts) + 1 - pval)/length(cuts)
-    }
-    pval <- t(pval)
-  }
-  if (is.null(labels)) {
-    if (is.null(rownames(r)))
-      rownames(r) <- paste("V", 1:nvar)
-    if (is.null(colnames(r)))
-      colnames(r) <- paste("V", 1:nf)
-  }
-  else {
-    rownames(r) <- colnames(r) <- labels
-  }
-  if (!is.null(min.length)) {
-    rownames(r) <- abbreviate(rownames(r), minlength = min.length)
-    colnames(r) <- abbreviate(colnames(r), minlength = min.length)
-  }
-  max.len <- max(nchar(rownames(r)))/6
-  if (is.null(zlim)) {
-    zlim <- range(r)
-  }
-  if (colors) {
-    if (missing(gr)) {
-      gr <- grDevices::colorRampPalette(c("red", "white", "blue"))
-    }
-    if (max(r, na.rm = TRUE) > 1) {
-      maxr <- max(r)
-      n1 <- n * (zlim[2] - zlim[1])/(maxr - zlim[1])
-      colramp <- rep(NA, n)
-      n1 <- ceiling(n1)
-      colramp[1:(n1 + 1)] <- gr(n1 + 1)
-      colramp[(n1 + 1):n] <- colramp[n1 + 1]
-      zlim[2] <- maxr
-    }
-    else {
-      colramp <- gr(n)
-    }
-  }
-  else {
-    colramp <- grDevices::grey((n:0)/n)
-  }
-  colramp <- grDevices::adjustcolor(colramp, alpha.f = alpha)
-  if (nvar != nf) {
-    r <- t(r)
-  }
-  ord1 <- seq(nvar, 1, -1)
-  if (nf == nvar) {
-    r <- r[, ord1]
-    pval <- pval[, ord1]
-  }
-  else {
-    r <- r[, ord1]
-    pval <- t(pval[ord1, ])
-  }
-  # graphics::par(mar = c(MAR + max.len, MAR + max.len, 4, 0.5))
-  graphics::par(mar = c(MAR + max.len, MAR + max.len, 2.5, 0.5))
-  if (show.legend) {
-    graphics::layout(matrix(c(1, 2), nrow = 1), widths = c(0.9, 0.1),
-      heights = c(1, 1))
-  }
-  graphics::image(r, col = colramp, axes = FALSE, main = main, zlim = zlim)
-  graphics::box()
-  at1 <- (0:(nf - 1))/(nf - 1)
-  at2 <- (0:(nvar - 1))/(nvar - 1)
-  lab1 <- rownames(r)
-  lab2 <- colnames(r)
-  if (xaxis == 3) {
-    line <- -0.5
-    tick <- FALSE
-  }
-  else {
-    line <- NA
-    tick <- TRUE
-  }
-  if (max.len > 0.5) {
-    graphics::axis(2, at = at2, labels = lab2, las = ylas, ...)
-    graphics::axis(xaxis, at = at1, labels = lab1, las = xlas, line = line,
-      tick = tick, ...)
-  }
-  else {
-    graphics::axis(2, at = at2, labels = lab2, las = ylas, ...)
-    graphics::axis(xaxis, at = at1, labels = lab1, las = xlas, line = line,
-      tick = tick, ...)
-  }
-  if (numbers) {
-    rx <- rep(at1, ncol(r))
-    ry <- rep(at2, each = nrow(r))
-    # rv <- round(r, 2)  # modified in bruceR
-    rv <- formatF(r, nsmall)  # modified in bruceR
-    if (stars) {
-      symp <- stats::symnum(pval, corr = FALSE, cutpoints = c(0,
-        0.001, 0.01, 0.05, 1), symbols = c("***", "**",
-        "*", " "), legend = FALSE)
-      rv[!is.na(rv)] <- paste0(rv[!is.na(rv)], symp[!is.na(rv)])
-      rv <- gsub("NA.*", "", rv)  # modified in bruceR
-      if (missing(cex))
-        cex = 9/max(nrow(r), ncol(r))
-      graphics::text(rx, ry, rv, cex = cex, ...)
-    }
-    else {
-      if (missing(cex))
-        cex = 9/max(nrow(r), ncol(r))
-      if (scale) {
-        graphics::text(rx, ry, rv, cex = pval * cex, ...)
-      }
-      else {
-        graphics::text(rx, ry, rv, cex = cex, ...)
-      }
-    }
-  }
-  if (show.legend) {
-    leg <- matrix(seq(from = zlim[1], to = zlim[2], by = (zlim[2] -
-      zlim[1])/n), nrow = 1)
-    # graphics::par(mar = c(MAR, 0, 4, 3))
-    graphics::par(mar = c(MAR, 0, 2.5, 3))
-    graphics::image(leg, col = colramp, axes = FALSE, zlim = zlim)
-    at2 <- seq(0, 1, 1/n.legend)
-    labels = seq(zlim[1], zlim[2], (zlim[2] - zlim[1])/(length(at2) -
-      1))
-    graphics::axis(4, at = at2, labels = labels, las = 2, ...)
-  }
-  invisible(R)
+  invisible(list(corr=cor, plot=p))
 }
 
 
@@ -1052,6 +869,94 @@ cor_diff = function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 }
 
 
+#' Multilevel correlations (within-level and between-level).
+#'
+#' Multilevel correlations (within-level and between-level).
+#' For details, see description in \code{\link{HLM_ICC_rWG}}.
+#'
+#' @inheritParams HLM_ICC_rWG
+#'
+#' @return Invisibly return a list of results.
+#'
+#' @seealso
+#' \code{\link{Corr}}
+#'
+#' \code{\link{HLM_ICC_rWG}}
+#'
+#' @examples
+#' # see https://psychbruce.github.io/supp/CEM
+#'
+#' @export
+cor_multilevel = function(
+    data, group, digits=3
+) {
+  Print("<<cyan
+  Correlations below and above the diagonal represent
+  within-level and between-level correlations, respectively:>>")
+
+  cors = suppressWarnings(psych::statsBy(data, group, cors=TRUE))
+
+  # Correlations between and within groups
+  rw = cors$rwg
+  rb = cors$rbg
+  rbw = rw
+  vars = rownames(cors$pooled)
+
+  # Reliabliity
+  # diag(rbw) = reliability
+
+  # Combine rwg & rbg
+  rbw[upper.tri(rbw)] = rb[upper.tri(rb)]
+  rownames(rbw) = vars
+  colnames(rbw) = vars
+  print_table(rbw, digits=digits)
+
+  # P values and 95% CI
+  pwg = cors$pwg
+  pbg = cors$pbg
+  rwg.ci = cors$ci.wg$r.ci
+  rbg.ci = cors$ci.bg$r.ci
+  if(!is.null(rwg.ci)) {
+    lower = upper = CI = NULL
+    rwg.ci = mutate(
+      rwg.ci,
+      CI = ifelse(
+        is.na(lower), "",
+        paste0("[", formatF(lower, digits),
+               ", ", formatF(upper, digits),
+               "]")),
+      pval = pwg[lower.tri(pwg)]
+    ) %>% rename(`[95% CI]`=CI)
+    print_table(rwg.ci[c("r", "[95% CI]", "pval")], digits,
+                title="\n\n\n<<cyan Within-Level Correlation [95% CI]:>>")
+  }
+  if(!is.null(rbg.ci)) {
+    rbg.ci = mutate(
+      rbg.ci,
+      CI = ifelse(
+        is.na(lower), "",
+        paste0("[", formatF(lower, digits),
+               ", ", formatF(upper, digits),
+               "]")),
+      pval = pbg[lower.tri(pbg)]
+    ) %>% rename(`[95% CI]`=CI)
+    print_table(rbg.ci[c("r", "[95% CI]", "pval")], digits,
+                title="\n\n\n<<cyan Between-Level Correlation [95% CI]:>>")
+  }
+
+  # ICC1 & ICC2
+  ICC = as.data.frame(rbind(cors$ICC1, cors$ICC2))[vars]
+  row.names(ICC) = c("ICC1", "ICC2")
+  print_table(ICC, digits,
+              title="\n\n\n<<cyan Intraclass Correlation:>>")
+
+  invisible(list(cors=rbw,
+                 rwg.ci=rwg.ci,
+                 rbg.ci=rbg.ci,
+                 icc=ICC))
+}
+
+
 #### T-Tests ####
 
 #' One-sample, independent-samples, and paired-samples t-test.
@@ -1092,10 +997,10 @@ cor_diff = function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #' Multiple variables should be included in a character vector \code{c()}.
 #'
 #' Only necessary for independent-samples \emph{t}-test.
-#' @param paired For paired-samples \emph{t}-test, set it as \code{TRUE}. Default is \code{FALSE}.
+#' @param paired For paired-samples \emph{t}-test, set it as \code{TRUE}. Defaults to \code{FALSE}.
 #' @param paired.d.type Type of Cohen's \emph{d} for paired-samples \emph{t}-test (see Lakens, 2013).
 #'
-#' Default is \code{"dz"}. Options include:
+#' Defaults to \code{"dz"}. Options include:
 #' \describe{
 #'   \item{\code{"dz"} (\emph{d} for standardized difference)}{
 #'     Cohen's \eqn{d_{z} = \frac{M_{diff}}{SD_{diff}}}
@@ -1109,15 +1014,15 @@ cor_diff = function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #'   }
 #' }
 #' @param var.equal If Levene's test indicates a violation of the homogeneity of variance,
-#' then you should better set this argument as \code{FALSE}. Default is \code{TRUE}.
-#' @param mean.diff Whether to display results of mean difference and its 95\% CI. Default is \code{TRUE}.
-#' @param test.value The true value of the mean (or difference in means for a two-samples test). Default is \code{0}.
+#' then you should better set this argument as \code{FALSE}. Defaults to \code{TRUE}.
+#' @param mean.diff Whether to display results of mean difference and its 95\% CI. Defaults to \code{TRUE}.
+#' @param test.value The true value of the mean (or difference in means for a two-samples test). Defaults to \code{0}.
 #' @param test.sided Any of \code{"="} (two-sided, the default), \code{"<"} (one-sided), or \code{">"} (one-sided).
 #' @param factor.rev Whether to reverse the levels of factor (X)
-#' such that the test compares higher vs. lower level. Default is \code{TRUE}.
-#' @param bayes.prior Prior scale in Bayesian \emph{t}-test. Default is 0.707.
+#' such that the test compares higher vs. lower level. Defaults to \code{TRUE}.
+#' @param bayes.prior Prior scale in Bayesian \emph{t}-test. Defaults to 0.707.
 #' See details in \code{\link[BayesFactor:ttestBF]{BayesFactor::ttestBF()}}.
-#' @param digits,nsmall Number of decimal places of output. Default is \code{2}.
+#' @param digits Number of decimal places of output. Defaults to \code{2}.
 #' @param file File name of MS Word (\code{.doc}).
 #'
 #' @examples
@@ -1200,17 +1105,19 @@ cor_diff = function(r1, n1, r2, n2, n=NULL, rcov=NULL) {
 #' A practical primer for \emph{t}-tests and ANOVAs. \emph{Frontiers in Psychology, 4}, Article 863.
 #'
 #' @export
-TTEST = function(data, y, x=NULL,
-                 paired=FALSE,
-                 paired.d.type="dz",
-                 var.equal=TRUE,
-                 mean.diff=TRUE,
-                 test.value=0,
-                 test.sided=c("=", "<", ">"),
-                 factor.rev=TRUE,
-                 bayes.prior="medium",
-                 digits=2, nsmall=digits,
-                 file=NULL) {
+TTEST = function(
+    data, y, x=NULL,
+    paired=FALSE,
+    paired.d.type="dz",
+    var.equal=TRUE,
+    mean.diff=TRUE,
+    test.value=0,
+    test.sided=c("=", "<", ">"),
+    factor.rev=TRUE,
+    bayes.prior="medium",
+    digits=2,
+    file=NULL
+) {
   data = as.data.frame(data)
 
   if(paired) {
@@ -1275,18 +1182,18 @@ TTEST = function(data, y, x=NULL,
   }
 
   ## Print (nmsd)
-  nmsd$MeanSD = paste0(formatF(nmsd$Mean, nsmall), " (",
-                       formatF(nmsd$S.D., nsmall), ")")
+  nmsd$MeanSD = paste0(formatF(nmsd$Mean, digits), " (",
+                       formatF(nmsd$S.D., digits), ")")
   names(nmsd)[length(nmsd)] = "Mean (S.D.)"
   nmsd$Mean = nmsd$S.D. = NULL
   Print("Descriptives:")
-  print_table(nmsd, row.names=FALSE, nsmalls=0)
+  print_table(nmsd, row.names=FALSE, digits=0)
   cat("\n")
 
   ## Print (check)
   if(nrow(lev)>0) {
     Print("Levene\u2019s test for homogeneity of variance:")
-    print_table(lev, nsmalls=c(2, 0, 0, 0))
+    print_table(lev, digits=c(2, 0, 0, 0))
     Print("<<italic Note>>: H0 = equal variance (homoscedasticity).
           If significant (violation of the assumption),
           then you should better set `var.equal=FALSE`.")
@@ -1295,9 +1202,9 @@ TTEST = function(data, y, x=NULL,
 
   ## Print (t-test)
   RES = res[,1:3]  # t, df, pval
-  RES$Diff = cc_m_ci(res$diff, res$llci, res$ulci, nsmall)
-  RES$Cohen = cc_m_ci(res$Cohen_d, res$LLCI, res$ULCI, nsmall)
-  RES$BF10 = sprintf(Glue("%.{nsmall}e"), res$BF10)
+  RES$Diff = cc_m_ci(res$diff, res$llci, res$ulci, digits)
+  RES$Cohen = cc_m_ci(res$Cohen_d, res$LLCI, res$ULCI, digits)
+  RES$BF10 = sprintf(Glue("%.{digits}e"), res$BF10)
   if(!is.null(file)) {
     RES$Diff = str_replace_all(RES$Diff, "-", "\u2013")
     RES$Cohen = str_replace_all(RES$Cohen, "-", "\u2013")
@@ -1316,7 +1223,7 @@ TTEST = function(data, y, x=NULL,
     RES[,4] = NULL
   print_table(
     RES,
-    nsmalls=c(nsmall, ifelse(var.equal, 0, nsmall), 0, 0, 0, 0, 0),
+    digits=c(digits, ifelse(var.equal, 0, digits), 0, 0, 0, 0, 0),
     title=ifelse(is.null(file),
                  Glue("Results of t-test{ifelse(var.equal, '', ' (adjusted df)')}:"),
                  type),
